@@ -1,8 +1,10 @@
 #ifndef MYS_HPP
 #define MYS_HPP
 
+#include "mys/memory.hpp"
 #include "mys/common.hpp"
 #include "mys/utils.hpp"
+#include "mys/traceback.hpp"
 
 // Mys defined types
 #include "mys/types/number.hpp"
@@ -22,8 +24,8 @@
 #include "mys/errors/base.hpp"
 #include "mys/errors/assertion.hpp"
 #include "mys/errors/index.hpp"
+#include "mys/errors/interrupt.hpp"
 #include "mys/errors/key.hpp"
-#include "mys/errors/none.hpp"
 #include "mys/errors/not_implemented.hpp"
 #include "mys/errors/system_exit.hpp"
 #include "mys/errors/unreachable.hpp"
@@ -32,7 +34,7 @@
 // Builtins, print, test and shared pointer functions
 #include "mys/builtins.hpp"
 #include "mys/test.hpp"
-#include "mys/sharedptr.hpp"
+#include "mys/shared_ptr.hpp"
 #include "mys/printable/char.hpp"
 #include "mys/printable/string.hpp"
 
