@@ -14,6 +14,10 @@ public:
 
     virtual void run() = 0;
 
+    bool __eq__(const mys::shared_ptr<Fiber>& other) {
+        return false;
+    }
+
     String __str__();
 };
 
@@ -33,4 +37,8 @@ bool sleep(f64 seconds);
 
 void init();
 
+void enable_signal(int signum);
+
+void disable_signal(int signum);
+
 }
