@@ -448,8 +448,9 @@ class FunctionVisitor(TypeVisitor):
     def visit_FunctionDef(self, node):
         decorators = visit_decorator_list(node.decorator_list,
                                           self.ALLOWED_DECORATORS)
+        is_macro = 'macro' in decorators
 
-        if 'macro' in decorators:
+        if is_macro:
             if not is_upper_snake_case(node.name):
                 raise CompileError("macro names must be upper case snake case", node)
         else:
@@ -460,6 +461,8 @@ class FunctionVisitor(TypeVisitor):
 
         if node.returns is None:
             returns = None
+        elif is_macro:
+            raise CompileError("macros cannot return anything", node)
         else:
             returns = FunctionVisitor().visit(node.returns)
 
@@ -472,7 +475,7 @@ class FunctionVisitor(TypeVisitor):
                         decorators.get('generic', []),
                         decorators.get('raises', []),
                         'test' in decorators,
-                        'macro' in decorators,
+                        is_macro,
                         args,
                         returns,
                         node,
@@ -517,9 +520,6 @@ def visit_decorator_list(decorator_list, allowed_decorators):
         elif isinstance(decorator, ast.Name):
             name = decorator.id
             values = []
-
-            if name == 'enum':
-                values.append('i64')
         else:
             raise CompileError("decorators must be @name or @name()", decorator)
 
@@ -530,15 +530,10 @@ def visit_decorator_list(decorator_list, allowed_decorators):
             raise CompileError(f"@{name} can only be given once", decorator)
 
         if name == 'enum':
-            if len(values) != 1:
-                raise CompileError(f"one parameter expected, got {len(values)}",
-                                   decorator)
+            if values:
+                raise CompileError("no parameters expected", decorator)
 
-            if values[0] not in INTEGER_TYPES:
-                raise CompileError(f"integer type expected, not '{values[0]}'",
-                                   decorator.args[0])
-
-            decorators['enum'] = values[0]
+            decorators['enum'] = None
         elif name == 'trait':
             if values:
                 raise CompileError("no parameters expected", decorator)
@@ -709,12 +704,23 @@ class DefinitionsVisitor(ast.NodeVisitor):
 
         return (name, value)
 
-    def visit_enum(self, node, decorators):
+    def visit_enum(self, node):
         enum_name = node.name
 
         if not is_pascal_case(enum_name):
             raise CompileError("enum names must be pascal case", node)
 
+        if len(node.bases) == 0:
+            type_name = 'i64'
+        elif len(node.bases) == 1:
+            type_name = node.bases[0].id
+
+            if type_name not in INTEGER_TYPES:
+                raise CompileError(f"integer type expected, not '{type_name}'",
+                                   node.bases[0])
+        else:
+            raise CompileError("multiple enum types given", node)
+
         self._next_enum_value = None
         members = []
         body_iter = iter(node.body)
@@ -730,7 +736,7 @@ class DefinitionsVisitor(ast.NodeVisitor):
 
         self._definitions.define_enum(enum_name,
                                       Enum(enum_name,
-                                           decorators['enum'],
+                                           type_name,
                                            members,
                                            docstring),
                                       node)
@@ -827,7 +833,7 @@ class DefinitionsVisitor(ast.NodeVisitor):
                                           ['enum', 'trait', 'generic'])
 
         if 'enum' in decorators:
-            self.visit_enum(node, decorators)
+            self.visit_enum(node)
         elif 'trait' in decorators:
             self.visit_trait(node)
         else:
