@@ -605,8 +605,6 @@ class ValueTypeVisitor(ast.NodeVisitor):
     def visit_call_builtin(self, name, node):
         if name in NUMBER_TYPES:
             return name
-        elif name == 'len':
-            return 'u64'
         elif name in ['str', 'string']:
             return 'string'
         elif name == 'char':
@@ -693,6 +691,8 @@ class ValueTypeVisitor(ast.NodeVisitor):
             return [value_type.key_type]
         elif name == 'values':
             return [value_type.value_type]
+        elif name == 'length':
+            return 'i64'
         else:
             raise InternalError(f"dict method '{name}' not supported", node)
 
