@@ -16,5 +16,5 @@ class Test(TestCase):
         shutil.copytree('tests/files/globals_init_order', f'tests/build/{name}')
 
         with Path(f'tests/build/{name}/mypkg'):
-            with patch('sys.argv', ['mys', '-d', 'test', '-v']):
+            with patch('sys.argv', ['mys', '-d', 'test']):
                 mys.cli.main()
